@@ -15,9 +15,7 @@
 #' @param gr Gradient or slope of road: -0.06, -0.04, -0.02, 0.00, 0.02. 0.04 or 0.06
 #' @param l Load of the vehicle: 0.0, 0.5 or 1.0
 #' @param p Character; pollutant: "CO", "FC", "NOx", "NO", "NO2", "HC", "PM", "NMHC", "CH4",
-#' "CO2",  "SO2" or "Pb". Only when p is "SO2" pr "Pb" x is needed. Also
-#' polycyclic aromatic hydrocarbons (PAHs), persistent organi pollutants (POPs),
-#' and Number of particles and Active Surface.
+#' "CO2",  "SO2" or "Pb". Only when p is "SO2" pr "Pb" x is needed. See notes.
 #' @param x Numeric; if pollutant is "SO2", it is sulphur in fuel in ppm, if is
 #' "Pb", Lead in fuel in ppm.
 #' @param k Multiplication factor
@@ -35,22 +33,14 @@
 #'
 #' \strong{Black Carbon and Organic Matter (g/km)}: "BC", "OM"
 #'
-#' \strong{PAH and POP (g/km)}: "indeno(1,2,3-cd)pyrene", "benzo(k)fluoranthene",
-#' "benzo(ghi)perylene", "fluoranthene",
-#' "benzo(a)pyrene", "pyrene", "perylene",  "anthanthrene", "benzo(b)fluorene",
-#' "benzo(e)pyrene", "triphenylene", "3,6-dimethyl-phenanthrene",
-#' "benzo(a)anthracene",  "phenanthrene", "napthalene",  "anthracene"
+#' \strong{PAH and POP (g/km)}:  See  \code{\link{speciate}}
+#' \strong{Dioxins and furans (g equivalent toxicity / km)}: See  \code{\link{speciate}}
 #'
-#' \strong{Dioxins and furans (g equivalent toxicity / km)}: "PCDD", "PCDF" and "PCB".
+#' \strong{Metals (g/km)}: See  \code{\link{speciate}}
 #'
-#' \strong{Metals (g/km)}: "As", "Cd", "Cr", "Cu", "Hg", "Ni", "Pb", "Se", "Zn" (g/km).
+#' \emph{Active Surface (cm2/km)} See  \code{\link{speciate}}
 #'
-#' \strong{NMHC (g/km)}: \code{\link{speciate}}
-#'
-#' \emph{Active Surface (cm2/km) (gr = 0 and l = 0.5)}: "AS_urban", "AS_rural", "AS_highway"
-#'
-#' \emph{Total Number of particles (N/km) (gr = 0 and l = 0.5)}: "N_urban", "N_rural", "N_highway",
-#' "N_50nm_urban", "N_50_100nm_rural", "N_100_1000nm_highway".
+#' \emph{Total Number of particles (N/km)}: See  \code{\link{speciate}}
 #'
 #' The available standards for Active Surface or number of particles are:
 #' Euro II and III
@@ -63,33 +53,17 @@
 #' The categories euro IV and euro V were assigned with euro III + SCR
 #'
 #'
-#' @seealso \code{\link{fuel_corr}} \code{\link{emis}} \code{\link{ef_ldv_cold}}
+#' @seealso \code{\link{fuel_corr}} \code{\link{emis}} \code{\link{ef_ldv_cold}}  \code{\link{speciate}}
 #' @export
 #' @examples \dontrun{
 #' # Quick view
-#' pol <- c("CO", "NOx", "HC", "NMHC", "CH4", "FC", "PM", "CO2", "SO2",
-#' "AS_urban", "AS_rural", "AS_highway",
-#' "N_urban", "N_rural", "N_highway",
-#' "N_50nm_urban", "N_50_100nm_rural", "N_100_1000nm_highway")
+#' pol <- c("CO", "NOx", "HC", "NMHC", "CH4", "FC", "PM", "CO2", "SO2")
 #' f <- sapply(1:length(pol), function(i){
 #' print(pol[i])
 #' ef_hdv_speed(v = "Trucks",t = "RT", g = "<=7.5", e = "II", gr = 0,
 #' l = 0.5, p = pol[i], x = 10)(30)
 #' })
 #' f
-#' # PAH POP
-#' ef_hdv_speed(v = "Trucks",t = "RT", g = "<=7.5", e = "II", gr = 0,
-#' l = 0.5, p = "napthalene", x = 10)(30)
-#' ef_hdv_speed(v = "Trucks",t = "RT", g = "<=7.5", e = "II", gr = 0,
-#' l = 0.5, p = "fluoranthene", x = 10)(30)
-#'
-#' # Dioxins and Furans
-#' ef_hdv_speed(v = "Trucks",t = "RT", g = "<=7.5", e = "II", gr = 0,
-#' l = 0.5, p = "PCB", x = 10)(30)
-#'
-#' # NMHC
-#' ef_hdv_speed(v = "Trucks",t = "RT", g = "<=7.5", e = "II", gr = 0,
-#' l = 0.5, p = "heptane", x = 10)(30)
 #'
 #' V <- 0:130
 #' ef1 <- ef_hdv_speed(v = "Trucks",t = "RT", g = "<=7.5", e = "II", gr = 0,
@@ -117,14 +91,8 @@
 ef_hdv_speed <- function(v, t, g, eu, x, gr = 0, l = 0.5 ,p, k=1,
                          show.equation = FALSE, speed, fcorr = rep(1, 8)){
   p_cri <- as.character(unique(sysdata$hdv_criteria$POLLUTANT))
-  p_met <- as.character(unique(sysdata$hdv_metals$POLLUTANT))
   p_ghg <- as.character(unique(sysdata$hdv_ghg$POLLUTANT))
-  p_pah <- as.character(unique(sysdata$hdv_pah$POLLUTANT))
-  p_nmhc <- as.character(unique(sysdata$hdv_nmhc$POLLUTANT))
-  p_pm <- as.character(unique(sysdata$hdv_pm$POLLUTANT))
-  xas <-  c("AS_urban", "AS_rural", "AS_highway")
-  npm <- c("N_urban", "N_rural", "N_highway",
-           "N_50nm_urban", "N_50_100nm_rural", "N_100_1000nm_highway")
+
   #Check eu
   if(is.matrix(eu) | is.data.frame(eu)){
     eu <- as.data.frame(eu)
@@ -135,16 +103,8 @@ ef_hdv_speed <- function(v, t, g, eu, x, gr = 0, l = 0.5 ,p, k=1,
 
   if(p %in% p_cri){
     ef_hdv <- sysdata$hdv_criteria
-  } else if(p %in%p_met){
-    ef_hdv <- sysdata$hdv_metals
   } else if(p %in% p_ghg){
     ef_hdv <- sysdata$hdv_ghg
-  } else if(p %in% p_pah){
-    ef_hdv <- sysdata$hdv_pah
-  } else if(p %in% p_nmhc){
-    ef_hdv <- sysdata$hdv_nmhc
-  } else if(p %in% p_pm){
-    ef_hdv <- sysdata$hdv_pm
   }
   # Check speed
   if(!missing(speed)){
@@ -208,16 +168,7 @@ ef_hdv_speed <- function(v, t, g, eu, x, gr = 0, l = 0.5 ,p, k=1,
         }
       }
       if(!missing(speed)){
-        if( p %in% xas) {
-          cat("Units of Active Surface: cm^2/km\n")
-          f1 <- f1(speed)
-          return(f1)
-        } else if (p %in% npm){
-          cat("Units of Number of Particles: n/km\n")
-          f1 <- f1(speed)
-        } else {
           f1 <- EmissionFactors(f1(speed))
-        }
         return(f1)
       } else {
         return(f1)
