@@ -40,9 +40,13 @@ emis_cold_td(veh = veh,
              verbose = TRUE)
 
 test_that("emis_cold works", {
-  expect_equal(round(emis_cold_td(veh = veh, lkm = lkm, ef = efh, efcold = efc[1:10, ],
-                                  beta = cold_lkm[,1], verbose = TRUE)$emissions[1]),
-               108)
+  expect_equal(round(emis_cold_td(veh = veh,
+                                  lkm = lkm,
+                                  ef = efh,
+                                  efcold = efc[1:10, ],
+                                  beta = cold_lkm[,1],
+                                  verbose = TRUE)$emissions[1]),
+               Emissions(108))
   expect_output(emis_cold_td(veh = veh, lkm = lkm, ef = efh, efcold = efc[1:10, ],
                              beta = cold_lkm[,1], verbose = TRUE),
                 "S.?")
@@ -53,10 +57,10 @@ test_that("emis_cold works", {
                                   beta = cold_lkm[,1], verbose = TRUE,
                                   params = list(paste0("data_", 1:10),
                                                 "moredata"))$emissions[1]),
-               108)
+               Emissions(108))
   expect_equal(round(emis_cold_td(veh = veh, lkm = lkm, ef = efh, efcold = efc,
                                   beta = cold_lkm, pro_month = veh_month, verbose = T)$emissions[1]),
-               7)
+               Emissions(7))
   efhh <- as.data.frame(
     matrix(seq_along(veh), nrow =  nrow(veh), ncol = ncol(veh)))
   expect_equal(round(emis_cold_td(veh = veh,
@@ -67,10 +71,10 @@ test_that("emis_cold works", {
                                   beta = cold_lkm,
                                   pro_month = veh_month,
                                   verbose = T)$emissions[1]),
-               30)
+               Emissions(30))
   expect_equal(round(emis_cold_td(veh = veh, lkm = lkm, ef = EmissionFactors(efhh), efcold = efc, fortran = T,
                                   beta = cold_lkm, pro_month = veh_month, verbose = T)$emissions[1]),
-               30)
+               Emissions(30))
   expect_message(round(emis_cold_td(veh = veh, lkm = lkm, ef = efh, efcold = efc,
                                     beta = cold_lkm,
                                     pro_month = veh_month,
@@ -86,7 +90,7 @@ test_that("emis_cold works", {
                                    pro_month = veh_month,
                                    verbose = T)$emissions[1]),
                 "S.?")
-  expect_equal(
+expect_equal(
     round(emis_cold_td(veh = veh,
                        lkm = lkm,
                        ef = efh,
@@ -95,7 +99,7 @@ test_that("emis_cold works", {
                        pro_month = veh_month,
                        verbose = FALSE,
                        params = list(paste0("data_", 1:10), "moredata"))$emissions[1]),
-    7)
+    Emissions(7))
 })
 
 
@@ -151,7 +155,8 @@ test_that("emis_cold works", {
                                   beta = cold_lkm,
                                   pro_month = df_month,
                                   verbose = T)$emissions[1]),
-               7)
+               Emissions(7))
+
   expect_equal(round(emis_cold_td(veh = veh,
                                   lkm = lkm,
                                   ef = EmissionFactors(as.numeric(efh[, 1:ncol(veh)])),
@@ -159,7 +164,7 @@ test_that("emis_cold works", {
                                   beta = cold_lkm,
                                   pro_month = df_month,
                                   verbose = T)$emissions[1]),
-               7)
+               Emissions(7))
 
   expect_equal(round(emis_cold_td(veh = veh,
                                   lkm = lkm,
@@ -169,7 +174,7 @@ test_that("emis_cold works", {
                                   pro_month = df_month,
                                   verbose = T,
                                   fortran = TRUE)$emissions[1]),
-               7)
+               Emissions(7))
 
   expect_equal(round(emis_cold_td(veh = veh,
                                   lkm = lkm,
@@ -179,7 +184,7 @@ test_that("emis_cold works", {
                                   pro_month = df_month,
                                   verbose = T,
                                   fortran = TRUE)$emissions[1]),
-               7)
+               Emissions(7))
 
   expect_error(emis_cold_td(veh = veh,
                             lkm = lkm,
@@ -201,7 +206,7 @@ test_that("emis_cold works", {
                                   beta = cold_lkm,
                                   pro_month = df_month,
                                   verbose = T)$emissions[1]),
-               30)
+               Emissions(30))
   expect_equal(round(emis_cold_td(veh = veh,
                                   lkm = lkm,
                                   ef = EmissionFactors(efhh),
@@ -210,7 +215,7 @@ test_that("emis_cold works", {
                                   beta = cold_lkm,
                                   pro_month = df_month,
                                   verbose = T)$emissions[1]),
-               30)
+               Emissions(30))
 })
 
 
